@@ -14,16 +14,20 @@ a = App()
 t = Text(a, text="Its a ListBox", color="black")
 
 listbox = ListBox(
-    a, 
-    items=["red", "green", "blue", "yellow", "purple", "turquoise", "pink", "orange", "black", "brown", "cyan"], 
-    selected="black", 
+    a,
+    items=["red", "green", "blue", "yellow", "purple", "turquoise", "pink", "orange", "black", "brown", "cyan"],
+    selected="black",
     command=change_color,
-    scrollbar=True)
+    scrollbar=True,
+    width="fill",
+    height="fill")
 
 mlistbox = ListBox(
-    a, 
-    items=["really", "slightly", "brilliant", "interesting", "but", "and", "rubbish", "stupid"], 
-    multiselect=True, 
-    command=update_text)
+    a,
+    items=["really", "slightly", "brilliant", "interesting", "but", "and", "rubbish", "stupid"],
+    multiselect=True,
+    command=update_text,
+    width="fill",
+    height="fill")
 
-a.display()
\ No newline at end of file
+a.display()
