@@ -17,7 +17,7 @@ class MenuBar(Component):
         # Create a tk Menu object within this object
         tk = Menu(master.tk)
 
-        super(MenuBar, self).__init__(master, tk, description)
+        super(MenuBar, self).__init__(master, tk, description, False)
 
         # Keep track of submenu objects
         self._sub_menus = []
