@@ -30,42 +30,32 @@ class Slider(TextWidget):
     def value(self, value):
         self.tk.set(value)
 
-    @property
-    def width(self):
-        if self._horizontal:
-            return self._get_tk_config("length")
-        else:
-            return self._get_tk_config("width")
-
-    @width.setter
-    def width(self, value):
-        if self._horizontal:
-            self._set_tk_config("length", value)
-        else:
-            self._set_tk_config("width", value)
-
-    @property
-    def height(self):
-        if self._horizontal:
-            return self._get_tk_config("width")
-        else:
-            return self._get_tk_config("length")
-
-    @height.setter
-    def height(self, value):
-        if self._horizontal:
-            self._set_tk_config("width", value)
-        else:
-            self._set_tk_config("length", value)
-
     def resize(self, width, height):
-        self.width = width
-        self.height = height
+        self._set_width(width)
+        self._set_height(height)
+        if width == "fill" or height == "fill":
+            self.master.display_widgets()
+    
+    def _set_width(self, width):
+        self._width = width
+        if width != "fill":
+            if self._horizontal:
+                self._set_tk_config("length", width)
+            else:
+                self._set_tk_config("width", width)
+    
+    def _set_height(self, height):
+        self._height = height
+        if height != "fill":
+            if self._horizontal:
+                self._set_tk_config("width", height)
+            else:
+                self._set_tk_config("length", height)
+
 
     # METHODS
     # ----------------
     # Calls the given function when the slider value is changed
-    
     def _command_callback(self, value):
         if self._command:
             args_expected = utils.no_args_expected(self._command)
@@ -84,7 +74,7 @@ class Slider(TextWidget):
 
     # DEPRECATED
     # -------------------------------------------
-        
+
     def add_command(self, command):
         self.update_command(command)
         utils.deprecated("Slider add_command() is deprecated - renamed to update_command()")
